@@ -129,12 +129,13 @@ def tuyaPlatform(apiRegion, apiKey, apiSecret, uri, token=None, new_sign_algorit
 
     return(response_dict)
 
-def wizard(color=True):
+def wizard(color=True, retries=None):
     """
     TinyTuya Setup Wizard Tuya based WiFi smart devices
 
     Parameter:
         color = True or False, print output in color [Default: True]
+        retries = Number of retries to find IP address of Tuya Devices
 
     Description
         Setup Wizard will prompt user for Tuya IoT Developer credentials and will gather all of
@@ -287,9 +288,13 @@ def wizard(color=True):
     answer = input(subbold + '\nPoll local devices? ' +
                    normal + '(Y/n): ')
     if(answer[0:1].lower() != 'n'):
+        # Set retries based on number of devices if undefined
+        if(retries == None):
+            retries = len(tuyadevices)+10+tinytuya.MAXCOUNT
+
         # Scan network for devices and provide polling data
-        print(normal + "\nScanning local network for Tuya devices...")
-        devices = tinytuya.deviceScan(False, 20)
+        print(normal + "\nScanning local network for Tuya devices (retry %d times)..." % retries)
+        devices = tinytuya.deviceScan(False, retries)
         print("    %s%s local devices discovered%s" %
               (dim, len(devices), normal))
         print("")
